@@ -1,9 +1,9 @@
 package Carp::Patch::Config;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2019-12-09'; # DATE
+our $DATE = '2020-06-19'; # DATE
 our $DIST = 'Carp-Patch-Config'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -33,26 +33,33 @@ sub patch_data {
 
 This is not an actual configuration for Carp, but a shortcut for:
 
-    # when value is 0
+    # when value is 0 or 'none'
     $Carp::RefArgFormatter = undef;
 
-    # when value is 1
+    # when value is 1 or 'Data::Dmp'
     $Carp::RefArgFormatter = sub {
         require Data::Dmp;
         Data::Dmp::dmp($_[0]);
     };
 
-    # when value is 2
+    # when value is 2 or 'Data::Dump'
     $Carp::RefArgFormatter = sub {
         require Data::Dump;
         Data::Dump::dump($_[0]);
     };
 
+    # when value is 3 or 'Data::Dump::ObjectAsString'
+    $Carp::RefArgFormatter = sub {
+        require Data::Dump::ObjectAsString;
+        Data::Dump::ObjectAsString::dump($_[0]);
+    };
+
 _
             },
         },
         after_patch => sub {
             no strict 'refs';
+            no warnings 'numeric';
             my $oldvals = {};
             for my $name (keys %config) {
                 my $carp_config_name = $name;
@@ -60,10 +67,11 @@ _
                 if ($name =~ /\A-?Dump\z/) {
                     $carp_config_name = 'RefArgFormatter';
                     $carp_config_val  =
-                        !$config{$name} ? undef :
-                        $config{$name} == 1 ? sub { require Data::Dmp ; Data::Dmp::dmp  ($_[0]) } :
-                        $config{$name} == 2 ? sub { require Data::Dump; Data::Dump::dump($_[0]) } :
-                        die "Unknown value for -Dump, please choose 0, 1, or 2";
+                        $config{$name} eq '0' || $config{$name} eq 'none' ? undef :
+                        $config{$name} == 1   || $config{$name} eq 'Data::Dmp'                  ? sub { require Data::Dmp ; Data::Dmp::dmp  ($_[0]) } :
+                        $config{$name} == 2   || $config{$name} eq 'Data::Dump'                 ? sub { require Data::Dump; Data::Dump::dump($_[0]) } :
+                        $config{$name} == 3   || $config{$name} eq 'Data::Dump::ObjectAsString' ? sub { require Data::Dump::ObjectAsString; Data::Dump::ObjectAsString::dump($_[0]) } :
+                        die "Unknown value for -Dump, please choose 0/none, 1/Data::Dmp, 2/Data::Dump, 3/Data::Dump::ObjectAsString";
                 }
                 $oldvals->{$carp_config_name} = ${"Carp::$carp_config_name"};
                 ${"Carp::$carp_config_name"} = $carp_config_val;
@@ -95,7 +103,7 @@ Carp::Patch::Config - Set some Carp variables
 
 =head1 VERSION
 
-This document describes version 0.005 of Carp::Patch::Config (from Perl distribution Carp-Patch-Config), released on 2019-12-09.
+This document describes version 0.006 of Carp::Patch::Config (from Perl distribution Carp-Patch-Config), released on 2020-06-19.
 
 =head1 SYNOPSIS
 
@@ -121,20 +129,26 @@ C<MaxArgLen>, C<MaxArgNums>.
 
 This is not an actual configuration for Carp, but a shortcut for:
 
- # when value is 0
+ # when value is 0 or 'none'
  $Carp::RefArgFormatter = undef;
  
- # when value is 1
+ # when value is 1 or 'Data::Dmp'
  $Carp::RefArgFormatter = sub {
      require Data::Dmp;
      Data::Dmp::dmp($_[0]);
  };
  
- # when value is 2
+ # when value is 2 or 'Data::Dump'
  $Carp::RefArgFormatter = sub {
      require Data::Dump;
      Data::Dump::dump($_[0]);
  };
+ 
+ # when value is 3 or 'Data::Dump::ObjectAsString'
+ $Carp::RefArgFormatter = sub {
+     require Data::Dump::ObjectAsString;
+     Data::Dump::ObjectAsString::dump($_[0]);
+ };
 
 
 =item * -MaxArgLen => int
@@ -175,7 +189,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
